==> transparentpath-0.1.23.tar.gz: transparentpath-0.1.23/docs/markdown/index.md <==
<!-- transparentpath documentation master file, created by
sphinx-quickstart on Thu Oct 7 17:55:25 2020.
You can adapt this file completely to your liking, but it should at least
contain the root `toctree` directive. -->
# Welcome to adutils’s documentation!

# transparentpath


* transparentpath package


    * Subpackages


        * transparentpath.gcsutils package


            * Submodules


            * transparentpath.gcsutils.methodtranslator module


            * transparentpath.gcsutils.transparentpath module


            * Module contents


        * transparentpath.jsonencoder package


            * Submodules


            * transparentpath.jsonencoder.jsonencoder module


            * Module contents


    * Module contents


# Changelog

## (unreleased)

### New


* First commit. [pcotte]

### Fix


* Added more versions to pytests. [pcotte]

### Other


* Merge pull request #6 from Advestis/dev. [pcotteadvestis]

chg: dev: try to have correct version


* Merge pull request #5 from Advestis/dev. [pcotteadvestis]

chg: dev: removed python version from push.yml


* Merge pull request #4 from Advestis/dev. [pcotteadvestis]

chg: dev: changed build to sdist


* Merge pull request #3 from Advestis/dev. [pcotteadvestis]

chg: dev: removed ref from push.yml


* Merge pull request #2 from Advestis/dev. [pcotteadvestis]

chg: dev: added other versions to pytests


* Merge pull request #1 from Advestis/dev. [pcotteadvestis]

fix: usr: added more versions to pytests

# Indices and tables


* Index


* Module Index


* Search Page

==> transparentpath-0.1.36.tar.gz: transparentpath-0.1.36/docs/markdown/index.md <==
<!-- transparentpath documentation master file, created by
sphinx-quickstart on Thu Oct 7 17:55:25 2020.
You can adapt this file completely to your liking, but it should at least
contain the root `toctree` directive. -->
# Welcome to transparentpath’s documentation!

# transparentpath


* transparentpath package


    * Subpackages


        * transparentpath.gcsutils package


            * Submodules


            * transparentpath.gcsutils.methodtranslator module


            * transparentpath.gcsutils.transparentpath module


            * Module contents


        * transparentpath.jsonencoder package


            * Submodules


            * transparentpath.jsonencoder.jsonencoder module


            * Module contents


    * Module contents


# Changelog

## (unreleased)

### New


* Instal.sh script. [pcotte]


* Added doc. [pcotte]


* Added doc. [pcotte]


* First commit. [pcotte]

### Changes


* Updated documentation. [pcotte]


* Clearer myisinstance. [pcotte]

### Fix


* Improved myisinstance by including the possibility to specify a list,
set or tuple of types. [pcotte]


* Added more versions to pytests. [pcotte]

### Other


* Merge pull request #6 from Advestis/dev. [pcotteadvestis]

chg: dev: try to have correct version


* Merge pull request #5 from Advestis/dev. [pcotteadvestis]

chg: dev: removed python version from push.yml


* Merge pull request #4 from Advestis/dev. [pcotteadvestis]

chg: dev: changed build to sdist


* Merge pull request #3 from Advestis/dev. [pcotteadvestis]

chg: dev: removed ref from push.yml


* Merge pull request #2 from Advestis/dev. [pcotteadvestis]

chg: dev: added other versions to pytests


* Merge pull request #1 from Advestis/dev. [pcotteadvestis]

fix: usr: added more versions to pytests

# Indices and tables


* Index


* Module Index


* Search Page
